@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.16'
+__version__ = '2.1.17'
 
 if os.environ.get('SERVER_SOFTWARE') is not None:
     # Google App Engine information
@@ -2029,12 +2029,14 @@ class SubmitMixin(AuthenticatedReddit):
     @decorators.restrict_access(scope='submit')
     @decorators.require_captcha
     def submit(self, subreddit, title, text=None, url=None, captcha=None,
-               save=None, send_replies=None):
+               save=None, send_replies=None, resubmit=None):
         """Submit a new link to the given subreddit.
 
         Accepts either a Subreddit object or a str containing the subreddit's
         display name.
 
+        :param resubmit: If True, submit the link even if it has already been
+            submitted.
         :param save: If True the new Submission will be saved after creation.
         :param send_replies: Gold Only Feature. If True, inbox replies will be
             received when people comment on the Submission. If set to None or
@@ -2058,6 +2060,8 @@ class SubmitMixin(AuthenticatedReddit):
             data['url'] = url
         if captcha:
             data.update(captcha)
+        if resubmit is not None:
+            data['resubmit'] = resubmit
         if save is not None:
             data['save'] = save
         if send_replies is not None:
