@@ -557,11 +557,6 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
             # pylint: enable-msg=W0212
         return self._replies
 
-    @property
-    def score(self):
-        """Return the comment's score."""
-        return self.ups - self.downs
-
     @property
     def submission(self):
         """Return the submission object this comment belongs to."""
